[−][src]Enum bracket_lib::prelude::BEvent
Available device events
Variants
The window was resized
The window was moved
Fields of Moved
new_position: PointThe window has requested that it be closed
A character was input
Fields of Character
c: charThe window gained or lost focus
Fields of Focused
focused: boolThe mouse cursor entered the window
The mouse cursor left the window
The mouse cursor moved
Fields of CursorMoved
position: PointA mouse button was pressed or released
Fields of MouseClick
pressed: boolMouse button is down
Fields of MouseButtonDown
Mouse button is up
Fields of MouseButtonUp
A key on the keyboard was pressed or released.
Fields of KeyboardInput
The window's scale factor was changed. You generally don't need to do anything for this, unless you are working with pixel coordinates.